using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinSpellChecker;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using System.Collections;

namespace TestSpellCheck
{
	public partial class InfragisticsTestForm : Form
	{
		public InfragisticsTestForm()
		{
			InitializeComponent();
		}



        #region Spell Checking

        #region Member Variables

        private ContextMenuStrip m_spellingContextMenu;
        private UltraSpellChecker m_ultraSpellChecker;

        //The maximum number of suggestions that are allowed to display in the context menu
        public const int MaxSuggestionsInContextMenu = 5;

        //A reference to the last clicked error in the rich text box (null if no error was clicked last)
        public Error m_lastClickedError = null;
        //A reference to the last clicked control
        public object m_lastClickedControl = null;

        private AsYouTypeManager m_AsYouTypeManager;



        #endregion






        protected void InitializeSpellChecking()
        {
            m_spellingContextMenu = new ContextMenuStrip();
            m_ultraSpellChecker = new UltraSpellChecker();
            m_ultraSpellChecker.Mode = SpellCheckingMode.AsYouType;
            //Setup User Dictionary
            SetupUserDictionary();

            m_spellingContextMenu.Opening += new CancelEventHandler(spellingContextMenu_Opening);


            //Hook the MouseDown event for the text box shown by the UltraTextEditor
            //This can only be done in the load if the UltraTextEditor's AlwaysInEditMode property is set to True.
            //Otherwise, it would have to be done in the AfterEnterEditMode event and the unhooked in the AfterExitEditMode event.
            ((Infragistics.Win.EditorWithText)this.txtIssueDescription.Editor).TextBox.MouseDown += new MouseEventHandler(this.SpellCheckedControl_MouseDown);

            //Set up the Context menu for the Checked Controls
            this.txtIssueDescription.ContextMenuStrip = m_spellingContextMenu;

            //Set up the SpellChecking for the Checked Controls
            this.txtIssueDescription.SpellChecker = m_ultraSpellChecker;

        }

        private void SetupUserDictionary()
        {

            string fileName = System.IO.Path.Combine(Application.StartupPath, "FtrUserDictionary.dict");
            try
            {
                if (!System.IO.File.Exists(fileName))
                {
                    System.IO.File.Create(fileName);
                }


                m_ultraSpellChecker.UserDictionary = fileName;
            }
            catch (Exception ex)
            {
            }

        }

        public void SpellCheckedControl_MouseDown(object sender, MouseEventArgs e)
        {
            this.m_lastClickedControl = sender;

            ////Get the error at the point where the user clicked in the spell checked control
            Point point = new Point(e.X, e.Y);
            this.m_lastClickedError = m_ultraSpellChecker.GetErrorAtPoint(sender, point);
        }


        protected void contextMenuSuggestion_Click(object sender, System.EventArgs e)
        {
            //Get the menu item that was clicked
            ToolStripItem suggestionItem = (ToolStripItem)sender;

            if (m_lastClickedControl.GetType() == typeof(UltraTextEditor))
            {
                UltraTextEditor ute = (UltraTextEditor)m_lastClickedControl;
                //Select the error in the text editor
                ute.Select(
                    this.m_lastClickedError.StartIndex,
                    this.m_lastClickedError.EndIndex - this.m_lastClickedError.StartIndex + 1);

                //Replace the selected error with the suggestion that was clicked
                ute.SelectedText = suggestionItem.Text;
                return;
            }
            if (m_lastClickedControl.GetType() == typeof(Infragistics.Win.EmbeddableTextBoxWithUIPermissions))
            {
                EmbeddableTextBoxWithUIPermissions eTe = (EmbeddableTextBoxWithUIPermissions)m_lastClickedControl;
                //Select the error in the text editor
                eTe.Select(
                    this.m_lastClickedError.StartIndex,
                    this.m_lastClickedError.EndIndex - this.m_lastClickedError.StartIndex + 1);

                //Replace the selected error with the suggestion that was clicked
                eTe.SelectedText = suggestionItem.Text;
                return;
            }
            if (m_lastClickedControl.GetType() == typeof(TextBox))
            {
                TextBox tb = (TextBox)m_lastClickedControl;
                //Select the error in the text editor
                tb.Select(
                    this.m_lastClickedError.StartIndex,
                    this.m_lastClickedError.EndIndex - this.m_lastClickedError.StartIndex + 1);

                //Replace the selected error with the suggestion that was clicked
                tb.SelectedText = suggestionItem.Text;
                return;
            }
            if (m_lastClickedControl.GetType() == typeof(RichTextBox))
            {
                RichTextBox rtb = (RichTextBox)m_lastClickedControl;
                //Select the error in the text editor
                rtb.Select(
                    this.m_lastClickedError.StartIndex,
                    this.m_lastClickedError.EndIndex - this.m_lastClickedError.StartIndex + 1);

                //Replace the selected error with the suggestion that was clicked
                rtb.SelectedText = suggestionItem.Text;
                return;
            }


        }
        protected void contextMenuAddToDictionary_Click(object sender, System.EventArgs e)
        {
            try
            {
                //Add the last clicked error to the user dictionary
                m_ultraSpellChecker.AddWordToUserDictionary(this.m_lastClickedError.CheckedWord);
            }
            catch (Exception)
            {

                throw;
            }
        }
        private void contextMenuIgnoreAll_Click(object sender, System.EventArgs e)
        {
            //Ignore all instances of the last clicked error
            m_ultraSpellChecker.IgnoreAll(this.m_lastClickedError.CheckedWord);
        }



        private void spellingContextMenu_Opening(object sender, CancelEventArgs e)
        {
            //Dispose all menu items that were previously added to the context menu
            foreach (ToolStripItem item in new ArrayList(m_spellingContextMenu.Items))
            {
                if (item != null)
                    item.Dispose();
            }

            //Clear the menu items previously added to the context menu
            m_spellingContextMenu.Items.Clear();

            //If the last clicked spot on the rich text box was over an error...
            if (this.m_lastClickedError != null)
            {
                //If there are no suggestions...
                if (this.m_lastClickedError.Suggestions.Count == 0)
                {
                    //Add the "no spelling suggestions" menu item and disable it
                    ToolStripItem noSuggestionsItem = m_spellingContextMenu.Items.Add("(no spelling suggestions)");
                    noSuggestionsItem.Enabled = false;
                }
                //Otherwise, if there are suggestions...
                else
                {
                    //Add suggestion menu items to the context menu
                    for (int i = 0; i < this.m_lastClickedError.Suggestions.Count; i++)
                    {
                        if (i >= MaxSuggestionsInContextMenu)
                            break;

                        m_spellingContextMenu.Items.Add(
                            this.m_lastClickedError.Suggestions[i], null,
                            new EventHandler(this.contextMenuSuggestion_Click));
                    }

                }

                //Add a separator item to the context menu
                m_spellingContextMenu.Items.Add("-");

                //Add the "Add to Dictionary" menu item
                ToolStripItem addItem = m_spellingContextMenu.Items.Add(
                    "Add to Dictionary", null,
                    new EventHandler(this.contextMenuAddToDictionary_Click));

                //Add the "Ignore All" menu item
                m_spellingContextMenu.Items.Add(
                    "Ignore All", null,
                    new EventHandler(this.contextMenuIgnoreAll_Click));



            }
        }


        #endregion

        private void InfragisticsTestForm_Load(object sender, EventArgs e)
        {
           InitializeSpellChecking();
        }

        private void InfragisticsTestForm_FormClosing(object sender, FormClosingEventArgs e)
        { 
        }

	}
}